/* @flow */
/**
 *  Copyright (c) 2015, Facebook, Inc.
 *  All rights reserved.
 *
 *  This source code is licensed under the BSD-style license found in the
 *  LICENSE file in the root directory of this source tree. An additional grant
 *  of patent rights can be found in the PATENTS file in the same directory.
 */

'use strict';

var _Object$defineProperty = require('babel-runtime/core-js/object/define-property')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

_Object$defineProperty(exports, '__esModule', {
  value: true
});

exports['default'] = DirectivesOfCorrectType;

var _error = require('../../error');

var _languagePrinter = require('../../language/printer');

var _typeDefinition = require('../../type/definition');

var _utilsIsValidLiteralValue = require('../../utils/isValidLiteralValue');

var _utilsIsValidLiteralValue2 = _interopRequireDefault(_utilsIsValidLiteralValue);

var _utilsFind = require('../../utils/find');

var _utilsFind2 = _interopRequireDefault(_utilsFind);

var _errors = require('../errors');

/**
 * Directive values of correct type
 *
 * A GraphQL document is only valid if all literal directive values are of the
 * correct expected type.
 */

function DirectivesOfCorrectType(context) {
  return {
    Directive: function Directive(node) {
      var directiveName = node.name.value;
      var valueAST = node.value;

      var directiveDef = (0, _utilsFind2['default'])(context.getSchema().getDirectives(), function (def) {
        return def.name === directiveName;
      });
      if (!directiveDef) {
        return false;
      }
      var typeDef = directiveDef.type;

      if (!valueAST && typeDef instanceof _typeDefinition.GraphQLNonNull) {
        return new _error.GraphQLError((0, _errors.missingDirectiveValueMessage)(directiveName, typeDef), [node]);
      }

      if (!typeDef && valueAST) {
        return new _error.GraphQLError((0, _errors.noDirectiveValueMessage)(directiveName), [valueAST]);
      }

      if (typeDef && valueAST && !(0, _utilsIsValidLiteralValue2['default'])(valueAST, typeDef)) {
        return new _error.GraphQLError((0, _errors.badDirectiveValueMessage)(directiveName, typeDef, (0, _languagePrinter.print)(valueAST)), [valueAST]);
      }
    }
  };
}

module.exports = exports['default'];